@@ -15,18 +15,18 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 18
-#define ARROW_VERSION_MINOR 1
-#define ARROW_VERSION_PATCH 0
+#define ARROW_VERSION_MAJOR 19
+#define ARROW_VERSION_MINOR 0
+#define ARROW_VERSION_PATCH 1
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "18.1.0"
+#define ARROW_VERSION_STRING "19.0.1"
 
-#define ARROW_SO_VERSION "1801"
-#define ARROW_FULL_SO_VERSION "1801.0.0"
+#define ARROW_SO_VERSION "1900"
+#define ARROW_FULL_SO_VERSION "1900.1.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
-#define ARROW_CXX_COMPILER_VERSION "19.1.6"
+#define ARROW_CXX_COMPILER_VERSION "20.1.0"
 #define ARROW_CXX_COMPILER_FLAGS " -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Qunused-arguments -fcolor-diagnostics  -Wa,-mbig-obj -Wall -Wno-unknown-warning-option -Wno-pass-failed -march=armv8-a "
 
 #define ARROW_BUILD_TYPE "RELEASE"
@@ -44,7 +44,7 @@
 /* #undef ARROW_JEMALLOC */
 /* #undef ARROW_JEMALLOC_VENDORED */
 #define ARROW_JSON
-/* #undef ARROW_MIMALLOC */
+#define ARROW_MIMALLOC
 /* #undef ARROW_ORC */
 #define ARROW_PARQUET
 /* #undef ARROW_SUBSTRAIT */
